from __future__ import division
import numpy as np
import lal
import lalsimulation
import time
from scipy.optimize import brentq
from lal import MSUN_SI, C_SI, G_SI

def get_fmin(M,eta,dt):
    """
    Compute the instantaneous frequency given a time till merger and the binary
    masses
    """
    M_SI = M*lal.MSUN_SI

    def dtchirp(f):
        """
        The chirp time to 2nd PN order
        """
        v = ((G_SI/C_SI**3)*M_SI*np.pi*f)**(1.0/3.0)
        temp = (v**(-8.0) + ((743.0/252.0) + 11.0*eta/3.0)*v**(-6.0) -
                (32*np.pi/5.0)*v**(-5.0) + ((3058673.0/508032.0) + 5429*eta/504.0 +
                (617.0/72.0)*eta**2)*v**(-4.0))
        return (5.0/(256.0*eta))*(G_SI/C_SI**3)*M_SI*temp - dt

    # solve for the frequency between limits
    fmin = brentq(dtchirp, 1e-6, 2000.0, xtol=1e-6)

    return fmin

m1 = 10.0   # the primary mass
m2 = 10.0   # the secondary mass
M = m1 + m2   # the total mass
eta = m1*m2/M**2     # the symmetric mass ratio
dt = 1e7    # the time until merger

# call the function 
fmin = get_fmin(M,eta,dt)
print('{}: signal frequency at {} prior to merger is {} Hz'.format(time.asctime(),dt,fmin))

exit(0)


